@@ -15,5 +15,8 @@ class DeviceTestHelper:
         app_config.device_id = device_id
         app_config.device_role = device_role
         app_config.ready()
-        assert device_id == app_config.device_id
-        assert device_role == app_config.device_role
+
+        if device_id != app_config.device_id:
+            self.fail("Device mismatch")
+        if device_role != app_config.device_role:
+            self.fail("Role mismatch")
