@@ -1,5 +1,20 @@
+import socket
+
 from django.apps import apps as django_apps
-from ipware import get_client_ip
+
+
+def get_client_ip(request):
+    x_forwarded_for = request.META.get("HTTP_X_FORWARDED_FOR")
+    if x_forwarded_for:
+        ip = x_forwarded_for.split(",")[0]
+    else:
+        ip = request.META.get("REMOTE_ADDR")
+    try:
+        socket.inet_aton(ip)
+    except socket.error:
+        return None
+    else:
+        return ip
 
 
 class EdcDeviceViewMixin:
@@ -19,5 +34,5 @@ class EdcDeviceViewMixin:
     def ip_address(self):
         client_ip = None
         if self.request:
-            client_ip, _ = get_client_ip(self.request)
+            client_ip = get_client_ip(self.request)
         return client_ip
